qualpal.Qualpal
===============

.. currentmodule:: qualpal

.. autoclass:: Qualpal
   :members:
   :show-inheritance:
   :inherited-members:
   :special-members: __call__, __add__, __mul__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Qualpal.generate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Qualpal.background
      ~Qualpal.colorspace_size
      ~Qualpal.cvd
      ~Qualpal.max_memory
      ~Qualpal.metric
   
   